<?php

namespace Drupal\link_filebrowser\Controller;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\OpenModalDialogCommand;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\StreamWrapper\PublicStream;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;

/**
 * Returns responses for Link filebrowser routes.
 */
class LinkFileBrowserController extends ControllerBase {

  /**
   * {@inheritDoc}
   */
  public function listFiles(Request $request) {
    $path = $request->query->get('scan');
    $public = PublicStream::basePath();
    $path = ltrim(str_replace($public, '', $path), '/');
    $response = $this->scan(implode('/', [DRUPAL_ROOT, $public, $path]));
    return new JsonResponse($response);
  }

  /**
   * {@inheritDoc}
   */
  public function showModalFileExplorer($field_id) {

    $response = new AjaxResponse();
    $title = $this->t('Files in shares folder');
    [$entity_type, $entity_bundle, $field_name] = explode('.', $field_id);
    $url = Url::fromRoute('link_filebrowser.scan', [
      'entity_type' => $entity_type,
      'entity_bundle' => $entity_bundle,
      'field_name' => $field_name,
    ]);
    // Attach the library necessary for using the Open(Modal)DialogCommand and
    // set the attachments for this Ajax response.
    $content['#attached']['library'][] = 'core/drupal.dialog.ajax';
    $content['text'] = [
      '#theme' => 'link_file_browser_popup',
      '#field_id' => $field_id,
      '#url_scan' => $url->toString(),
      '#folder' => '/' . $this->getFolder($entity_type, $entity_bundle, $field_name),
    ];
    $options = [
      'dialogClass' => 'views-ui-dialog js-views-ui-dialog',
      'width' => '75%',
    ];
    $response->addCommand(new OpenModalDialogCommand($title, $content, $options));
    return $response;
  }

  /**
   * {@inheritDoc}
   */
  public function scanFiles($entity_type, $entity_bundle, $field_name) {
    // Output the directory listing as JSON.
    $response = $this->scan($this->getFolder($entity_type, $entity_bundle, $field_name));
    return new JsonResponse($response);
  }

  /**
   * {@inheritDoc}
   */
  public function getFolder($entity_type, $entity_bundle, $field_name) {
    $temp = explode('-', $field_name);
    $field_name = $temp[0];
    $form_mode = 'default';
    $field_widget_settings = \Drupal::entityTypeManager()
      ->getStorage('entity_form_display')
      ->load($entity_type . '.' . $entity_bundle . '.' . $form_mode)
      ->getComponent($field_name)['settings'];
    $directory = !empty($field_widget_settings["folder"]) ? '/' . $field_widget_settings["folder"] : '/';
    // Get directory in field widget config.
    $path = PublicStream::basePath();
    return $path . $directory;
  }

  /**
   * Get files in directory.
   *
   * {@inheritDoc}
   */
  public function scan($dir) {

    $files = [];
    // Is there actually such a folder/file?
    if (file_exists($dir)) {
      foreach (scandir($dir) as $f) {
        if (!$f || $f[0] == '.') {
          // Ignore hidden files.
          continue;
        }
        if (is_dir($dir . '/' . $f)) {
          // The path is a folder.
          $files[$f] = $this->scan($dir . '/' . $f);
        }
        else {
          // It is a file.
          $files[$f] = '/' . $dir . '/' . $f;
        }
      }
    }
    return $files;
  }

}
