<?php

namespace Drupal\link_filebrowser\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Provides a file browser block.
 *
 * @Block(
 *   id = "link_filebrowser",
 *   admin_label = @Translation("File browser"),
 *   category = @Translation("File browser")
 * )
 */
class FileBrowserBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'folder' => '',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form['folder'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Path folder to browser'),
      '#default_value' => $this->configuration['folder'],
      '#required' => TRUE,
      '#description' => $this->t('Folder must be in public://.'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->configuration['folder'] = $values['folder'];
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = $this->getConfiguration();
    $url = Url::fromRoute('link_filebrowser.list_files');
    $build['content'] = [
      '#theme' => 'link_file_browser_block',
      '#url_scan' => $url->toString(),
      '#folder' => $config['folder'],
      '#attributes' => [
        'class' => [
          'browser-block',
        ],
      ],
    ];
    $build['#attached']['library'][] = 'link_filebrowser/browser.block';

    return $build;
  }

}
