<?php

namespace Drupal\link_filebrowser\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Url;
use Drupal\link\Plugin\Field\FieldFormatter\LinkFormatter;

/**
 * Plugin implementation of the 'explorer_link' formatter.
 *
 * @FieldFormatter(
 *   id = "explorer_link",
 *   label = @Translation("Link with File browser"),
 *   field_types = {
 *     "link"
 *   }
 * )
 */
class ExplorerLinkFormatter extends LinkFormatter {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = parent::viewElements($items, $langcode);
    foreach ($elements as $delta => &$element) {
      $url = $element["#url"];
      if (!$url->isRouted()) {
        $uri = str_replace('base:', '', $url->getUri());
        $realpath = \Drupal::service('file_system')->realpath($uri);
        if (is_dir($realpath)) {
          $elements[$delta]["#options"]["attributes"]['class'][] = 'explorer';
          $url = Url::fromRoute('link_filebrowser.list_files');
          $elements[$delta]["#options"]["attributes"]['data-url_scan'] = $url->toString();
        }
      }
    }
    $elements['#attached']['library'][] = 'link_filebrowser/browser';
    return $elements;
  }

}
